django_analyses.models.input.types package — django_analyses 0.0.3 documentation

# django_analyses.models.input.types package

## Submodules

## django_analyses.models.input.types.boolean_input module

class `django_analyses.models.input.types.boolean_input.` `BooleanInput`(id, run, input_ptr, value, definition)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.directory_input module

class `django_analyses.models.input.types.directory_input.` `DirectoryInput`(id, run, input_ptr, value, definition)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  property `default_output_directory`
  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `fix_output_path`() → str
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `pre_save`() → None
  property `required_path`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.file_input module

class `django_analyses.models.input.types.file_input.` `FileInput`(id, run, input_ptr, value, definition)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.float_input module

class `django_analyses.models.input.types.float_input.` `FloatInput`(id, run, input_ptr, numberinput_ptr, value, definition)

  Bases: `django_analyses.models.input.types.number_input.NumberInput`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.types.number_input.NumberInput.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.types.number_input.NumberInput.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `numberinput_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `numberinput_ptr_id`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.input_types module

class `django_analyses.models.input.types.input_types.` `InputTypes`

  Bases: `enum.Enum`

  An enumeration.

  `BLN` = 'Boolean'
  `DIR` = 'Directory'
  `FIL` = 'File'
  `FLT` = 'Float'
  `INT` = 'Integer'
  `LST` = 'List'
  `STR` = 'String'

## django_analyses.models.input.types.integer_input module

class `django_analyses.models.input.types.integer_input.` `IntegerInput`(id, run, input_ptr, numberinput_ptr, value, definition)

  Bases: `django_analyses.models.input.types.number_input.NumberInput`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.types.number_input.NumberInput.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.types.number_input.NumberInput.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `numberinput_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `numberinput_ptr_id`
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.list_input module

class `django_analyses.models.input.types.list_input.` `ListInput`(id, run, input_ptr, value, definition)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  property `expected_type`
  property `expected_type_definition`
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `raise_incorrect_type_error`() → None
  `raise_max_length_error`() → None
  `raise_min_length_error`() → None
  `raise_not_list_error`() → None
  property `valid_elements`
  property `valid_max_length`
  property `valid_min_length`
  `validate`() → None
  classmethod `validate_element_types`(value: list, expected_type: type) → bool
  `validate_max_length`() → bool
  `validate_min_length`() → bool
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.types.number_input module

class `django_analyses.models.input.types.number_input.` `NumberInput`(id, run, input_ptr)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  `floatinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `integerinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `raise_max_value_error`() → None
  `raise_min_value_error`() → None
  property `valid_max_value`
  property `valid_min_value`
  `validate`() → None
  `validate_max_value`() → bool
  `validate_min_value`() → bool

## django_analyses.models.input.types.string_input module

class `django_analyses.models.input.types.string_input.` `StringInput`(id, run, input_ptr, value, definition)

  Bases: `django_analyses.models.input.input.Input`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.input.Input.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.input.Input.MultipleObjectsReturned`

  property `default_output_directory`
  property `default_value_formatting_dict`
  `definition`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `definition_id`
  `fix_output_path`() → str
  `get_default_value_formatting_dict`() → dict
  `get_type`() → django_analyses.models.input.types.input_types.InputTypes
  `input_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `input_ptr_id`
  `pre_save`() → None
  `raise_invalid_choice_error`() → None
  `raise_max_length_error`() → None
  `raise_min_length_error`() → None
  property `required_path`
  property `valid_choice`
  property `valid_max_length`
  property `valid_min_length`
  `validate`() → None
  `validate_from_choices`() → bool
  `validate_max_length`() → bool
  `validate_min_length`() → bool
  `value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## Module contents